==> ejc-ztpcdc-impl-3.0.0-20230608.013305-63-sources.jar: com/ejianc/business/dc/bean/DcDrawdistributeDrawinfoEntity.java <==
package com.ejianc.business.dc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 图纸签发/图纸申请-图纸信息
 *
 * @author generator
 */
@TableName("dc_drawdistribute_drawinfo")
public class DcDrawdistributeDrawinfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "pid")
    private Long pid; // 图纸签发表/图纸申请表主键id
    @TableField(value = "order_num")
    private Integer orderNum; // 顺序号
    @TableField(value = "draw_id")
    private Long drawId; // 图纸id
    @TableField(value = "drwgrp_id")
    private Long drwgrpId; // 卷册ID
    @TableField(value = "draw_code")
    private String drawCode; // 图纸编号
    @TableField(value = "draw_name")
    private String drawName; // 图纸名称
    @TableField(value = "draw_vsn")
    private String drawVsn; // 图纸版本
    @TableField(value = "drwgrp_code")
    private String drwgrpCode; // 卷册编号
    @TableField(value = "drwgrp_vsn")
    private String drwgrpVsn; // 卷册版本
    @TableField(value = "draw_type")
    private Long drawType; // 图纸类型
    @TableField(value = "transfer_code")
    private String transferCode; // 传递单号
    @TableField(value = "draw_arrive_date")
    private Date drawArriveDate; // 到图日期
    @TableField(value = "draw_attachment")
    private String drawAttachment; // 图纸附件
    @TableField(value = "create_dept_id")
    private Long createDeptId; // 创建部门id

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Integer getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(Integer orderNum) {
        this.orderNum = orderNum;
    }

    public Long getDrawId() {
        return drawId;
    }

    public void setDrawId(Long drawId) {
        this.drawId = drawId;
    }

    public Long getDrwgrpId() {
        return drwgrpId;
    }

    public void setDrwgrpId(Long drwgrpId) {
        this.drwgrpId = drwgrpId;
    }

    public String getDrawCode() {
        return drawCode;
    }

    public void setDrawCode(String drawCode) {
        this.drawCode = drawCode;
    }

    public String getDrawName() {
        return drawName;
    }

    public void setDrawName(String drawName) {
        this.drawName = drawName;
    }

    public String getDrawVsn() {
        return drawVsn;
    }

    public void setDrawVsn(String drawVsn) {
        this.drawVsn = drawVsn;
    }

    public String getDrwgrpCode() {
        return drwgrpCode;
    }

    public void setDrwgrpCode(String drwgrpCode) {
        this.drwgrpCode = drwgrpCode;
    }

    public String getDrwgrpVsn() {
        return drwgrpVsn;
    }

    public void setDrwgrpVsn(String drwgrpVsn) {
        this.drwgrpVsn = drwgrpVsn;
    }

    public Long getDrawType() {
        return drawType;
    }

    public void setDrawType(Long drawType) {
        this.drawType = drawType;
    }

    public String getTransferCode() {
        return transferCode;
    }

    public void setTransferCode(String transferCode) {
        this.transferCode = transferCode;
    }

    public Date getDrawArriveDate() {
        return drawArriveDate;
    }

    public void setDrawArriveDate(Date drawArriveDate) {
        this.drawArriveDate = drawArriveDate;
    }

    public String getDrawAttachment() {
        return drawAttachment;
    }

    public void setDrawAttachment(String drawAttachment) {
        this.drawAttachment = drawAttachment;
    }

    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }

}

==> ejc-ztpcdc-impl-3.0.0-20231221.004858-259-sources.jar: com/ejianc/business/dc/bean/DcDrawdistributeDrawinfoEntity.java <==
package com.ejianc.business.dc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 图纸签发/图纸申请-图纸信息
 *
 * @author generator
 */
@TableName("dc_drawdistribute_drawinfo")
public class DcDrawdistributeDrawinfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "pid")
    private Long pid; // 图纸签发表/图纸申请表主键id
    @TableField(value = "order_num")
    private Integer orderNum; // 顺序号
    @TableField(value = "draw_id")
    private Long drawId; // 图纸id
    @TableField(value = "drwgrp_id")
    private Long drwgrpId; // 卷册ID
    @TableField(value = "draw_code")
    private String drawCode; // 图纸编号
    @TableField(value = "draw_name")
    private String drawName; // 图纸名称
    @TableField(value = "draw_vsn")
    private String drawVsn; // 图纸版本
    @TableField(value = "drwgrp_code")
    private String drwgrpCode; // 卷册编号
    @TableField(value = "drwgrp_vsn")
    private String drwgrpVsn; // 卷册版本
    @TableField(value = "draw_type")
    private Long drawType; // 图纸类型
    @TableField(value = "transfer_code")
    private String transferCode; // 传递单号
    @TableField(value = "draw_arrive_date")
    private Date drawArriveDate; // 到图日期
    @TableField(value = "draw_attachment")
    private String drawAttachment; // 图纸附件
    @TableField(value = "create_dept_id")
    private Long createDeptId; // 创建部门id
    @TableField(value="print_status")
    private String printStatus; // 打印状态（0：未打印，2：已打印）
    @TableField(value="paper_flag")
    private String paperFlag; // 是否纸质版（Y：是，N：否）

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Integer getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(Integer orderNum) {
        this.orderNum = orderNum;
    }

    public Long getDrawId() {
        return drawId;
    }

    public void setDrawId(Long drawId) {
        this.drawId = drawId;
    }

    public Long getDrwgrpId() {
        return drwgrpId;
    }

    public void setDrwgrpId(Long drwgrpId) {
        this.drwgrpId = drwgrpId;
    }

    public String getDrawCode() {
        return drawCode;
    }

    public void setDrawCode(String drawCode) {
        this.drawCode = drawCode;
    }

    public String getDrawName() {
        return drawName;
    }

    public void setDrawName(String drawName) {
        this.drawName = drawName;
    }

    public String getDrawVsn() {
        return drawVsn;
    }

    public void setDrawVsn(String drawVsn) {
        this.drawVsn = drawVsn;
    }

    public String getDrwgrpCode() {
        return drwgrpCode;
    }

    public void setDrwgrpCode(String drwgrpCode) {
        this.drwgrpCode = drwgrpCode;
    }

    public String getDrwgrpVsn() {
        return drwgrpVsn;
    }

    public void setDrwgrpVsn(String drwgrpVsn) {
        this.drwgrpVsn = drwgrpVsn;
    }

    public Long getDrawType() {
        return drawType;
    }

    public void setDrawType(Long drawType) {
        this.drawType = drawType;
    }

    public String getTransferCode() {
        return transferCode;
    }

    public void setTransferCode(String transferCode) {
        this.transferCode = transferCode;
    }

    public Date getDrawArriveDate() {
        return drawArriveDate;
    }

    public void setDrawArriveDate(Date drawArriveDate) {
        this.drawArriveDate = drawArriveDate;
    }

    public String getDrawAttachment() {
        return drawAttachment;
    }

    public void setDrawAttachment(String drawAttachment) {
        this.drawAttachment = drawAttachment;
    }

    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }

    public String getPrintStatus() {
        return printStatus;
    }

    public void setPrintStatus(String printStatus) {
        this.printStatus = printStatus;
    }

    public String getPaperFlag() {
        return paperFlag;
    }

    public void setPaperFlag(String paperFlag) {
        this.paperFlag = paperFlag;
    }
}
